Add `-fpch-instantiate-templates` to the clang precompiled header generation command.
Testing with `make hotspot`, I observe a 40% reduction in build CPU time for a release build. On a 56 core machine, this reduces the wall time of the same command by 25% (45.94s -> 34.5s). --------- - [x] I confirm that I make this contribution in accordance with the [OpenJDK Interim AI Policy](https://openjdk.org/legal/ai). ------------- Commit messages: - 8395850: precompiled header template instantiation Changes: https://git.openjdk.org/jdk/pull/33576/files Webrev: https://webrevs.openjdk.org/?repo=jdk&pr=33576&range=00 Issue: https://bugs.openjdk.org/browse/JDK-8395850 Stats: 3 lines in 1 file changed: 1 ins; 0 del; 2 mod Patch: https://git.openjdk.org/jdk/pull/33576.diff Fetch: git fetch https://git.openjdk.org/jdk.git pull/33576/head:pull/33576 PR: https://git.openjdk.org/jdk/pull/33576
